@@ -15,16 +15,14 @@ that are not unit length, but this may vary from
 function to function.
 """
 from __future__ import absolute_import, division, print_function, unicode_literals
-
-import numpy
-
-from pyrr import vector
-from pyrr.utils import all_parameters_as_numpy_arrays, parameters_as_numpy_arrays
+import numpy as np
+from . import vector
+from .utils import all_parameters_as_numpy_arrays, parameters_as_numpy_arrays
 
 
 class index:
-    #: The index of the origin vector within the ray
-    origin = 0
+    #: The index of the start vector within the ray
+    position = 0
 
     #: The index of the direction vector within the ray
     direction = 1
@@ -33,7 +31,7 @@ class index:
 @parameters_as_numpy_arrays('start', 'direction')
 def create(start, direction, dtype=None):
     dtype = dtype or start.dtype
-    return numpy.array(
+    return np.array(
         [
             start,
             vector.normalise(direction)
@@ -47,7 +45,7 @@ def create_from_line(line, dtype=None):
     """
     dtype = dtype or line.dtype
     # direction = vend - vstart
-    return numpy.array(
+    return np.array(
         [
             line[0],
             vector.normalise(line[1] - line[0])
@@ -55,45 +53,17 @@ def create_from_line(line, dtype=None):
         dtype=dtype
     )
 
-def create_xy(invert=False, dtype=None):
-    """Create a plane on the XY plane, starting at the origin with +Z being
-    the up vector.
-    """
-    r = create_ray(
-        numpy.array([0.,0.,0.], dtype=dtype),
-        numpy.array([0.,0.,1.], dtype=dtype)
-    )
-    if invert:
-        r[1] *= -1
-    return r
-
-def create_xz(invert=False, dtype=None):
-    r = create_ray(
-        numpy.array([0.,0.,0.], dtype=dtype),
-        numpy.array([0.,1.,0.], dtype=dtype)
-    )
-    if invert:
-        r[1] *= -1
-    return r
-
-def create_yz(invert=False, dtype=None):
-    r = create_ray(
-        numpy.array([0.,0.,0.], dtype=dtype),
-        numpy.array([1.,0.,0.], dtype=dtype)
-    )
-    if invert:
-        r[1] *= -1
-    return r
-
 @all_parameters_as_numpy_arrays
 def invert(r):
     r2 = r.copy()
     r2[1] *= -1
     return r2
 
-def start(ray):
+@all_parameters_as_numpy_arrays
+def position(ray):
     return ray[0].copy()
 
+@all_parameters_as_numpy_arrays
 def direction(ray):
     return ray[1].copy()
 
