@@ -1,26 +1,30 @@
 # -*- coding: utf-8 -*-
 """Provides functions for creating and manipulating 4D vectors.
 """
-import numpy
-from pyrr.utils import parameters_as_numpy_arrays
+from __future__ import absolute_import, division, print_function, unicode_literals
+import numpy as np
+from .utils import parameters_as_numpy_arrays
+
+# import common vector operations
+from .vector import *
 
 
-def create(x=0, y=0, z=0, w=1.0, dtype=None):
-    return numpy.array([x,y,z,w], dtype=dtype)
+def create(x=0., y=0., z=0., w=1.0, dtype=None):
+    return np.array([x,y,z,w], dtype=dtype)
 
 def create_unit_length_x(dtype=None):
-    return numpy.array([1.0, 0.0, 0.0, 1.0], dtype=dtype)
+    return np.array([1.0, 0.0, 0.0, 1.0], dtype=dtype)
 
 def create_unit_length_y(dtype=None):
-    return numpy.array([0.0, 1.0, 0.0, 1.0], dtype=dtype)
+    return np.array([0.0, 1.0, 0.0, 1.0], dtype=dtype)
 
 def create_unit_length_z(dtype=None):
-    return numpy.array([0.0, 0.0, 1.0, 1.0], dtype=dtype)
+    return np.array([0.0, 0.0, 1.0, 1.0], dtype=dtype)
 
 @parameters_as_numpy_arrays('vector')
 def create_from_vector3(vector, dtype=None):
     dtype = dtype or vector.dtype
-    return numpy.array([vec[0], vec[1], vec[2], 1.0], dtype=dtype)
+    return np.array([vector[0], vector[1], vector[2], 1.0], dtype=dtype)
 
 def create_from_matrix44_translation(mat):
     return mat[3, 0:4].copy()
